==> vuejs-1.0.25.tgz: package/docs/element-ui/form.md <==
## 基于 element-ui 表单组件封装扩展
| 组件名称 | 组件路径 | 组件说明
| :--- | :--- | :--- |
| nftn-el-input | /components/element-ui/form/input.vue | 输入组件 |
| nftn-el-form | /components/element-ui/form/main.vue | 表单组件 |

### 依赖内容
| 依赖名称 | 依赖路径 | 依赖说明
| :--- | :--- | :--- |
| nftn-el-grid | /components/element-ui/grid/main.vue | 内部网格组件 |
| moxie-file | /component/moxie/file.vue | moxie 文件组件 |
| moxie-preview | /component/moxie/preview.vue | moxie 文件组件 |
| el-radio-group + el-radio | http://element.eleme.io/#/zh-CN/component/radio | element-ui 单选组件 |
| el-checkbox-group + el-checkbox | http://element.eleme.io/#/zh-CN/component/checkbox | element-ui 复选组件 |
| el-select | http://element.eleme.io/#/zh-CN/component/select | element-ui 下拉组件 |
| el-date-picker | http://element.eleme.io/#/zh-CN/component/date-picker | element-ui 日期组件 |
| el-switch | http://element.eleme.io/#/zh-CN/component/switch | element-ui 开关组件 |
| el-slider | http://element.eleme.io/#/zh-CN/component/slider | element-ui 滑块组件 |
| el-input | http://element.eleme.io/#/zh-CN/component/input | element-ui 输入组件 |
| el-form + el-form-item | http://element.eleme.io/#/zh-CN/component/form | element-ui 表单组件 |

### props
#### /components/element-ui/form.vue
| 参数名称 | 参数类型 | 参数说明 | 可选值 | 默认值 |
| :--- | :--- | :--- | :--- | :--- |
| --- __显示相关__ --- |
| grid | [Object, Array] | 表单网格布局 | /components/element-ui/grid/main.vue | `{}` |
| actionGridSlot | String | 表单按钮所在网格位置 | 网格范围 | 网格最后一格<br>`(rows.length - 1) + '-' + (cols.length - 1)` |
| labelPosition | String | 表单名称显示位置 | `'top'`<br>`'left'`<br>`'right'` | `'top'`
| labelWidth | Number | 表单名称显示长度 | -- | `80` |
| inputs | Array | 表单项集合 | /components/element-ui/input.vue | -- |
| --- __功能相关__ --- |
| rules | Object | 规则自动合并到 input.rules 数组中 | -- | `{}` |
| emptyNoPost | Boolean | 数据为空时是否提交<br>表单项单独配置为准 | `true`<br>`false` | `false` |
| --- __其他___ --- |
| value | Any | 数据值绑定<br>`v-model` | -- | '' |

#### /components/element-ui/input.vue
| 参数名称 | 参数类型 | 参数说明 | 可选值 | 默认值 |
| :--- | :--- | :--- | :--- | :--- |
| --- __显示相关__ --- |
| label | String | 输入项名称 | -- | -- |
| type | String | 输入项类型 | `'radio'`<br>`'checkbox'`<br>`'select'`<br>`'date'`<br>`'daterange'`<br>`'switch'`<br>`'slider'`<br>`'file'`<br>`'text'` | `'text'` |
| disabled | Boolean | 是否禁用 | `true`<br>`false` | `false` |
| errors | Array | 输入项错误信息 |  -- | -- |
| rows | Number | 文本行数<br>`type='textarea'` | -- | `3` |
| format | String | 日期显示格式<br>`type='date'`<br>`type='datetime'` | -- | `'yyyy-MM-dd'` |
| onText | String | 打开时显示文字<br>`type='switch'` | -- | `'开`' |
| offText | String | 关闭时显示文字<br>`type='switch'` | -- | `'关'` |
| onValue | Any | 打开时数据值<br>`type='switch'` | -- | `true` |
| offValue | Any | 关闭时数据值<br>`type='switch'` | -- | `false` |
| onColor | String | 打开时显示颜色<br>`type='switch'`<br> | -- | `'#20A0FF'` |
| offColor | String | 关闭时显示颜色<br>`type='switch'`<br> | -- | `'#C0CCDA'` |
| vertical | Boolean | 是否纵向显示<br>`type='switch'` | `true`<br>`false`| `false` |
| height | String | 设定高度值<br>`type='switch'` | `?? + 'px'` | `'100px'` |
| grid | Object | 网格展示<br>`type='file'` | /components/element-ui/grid/main.vue | `{ gap: 10, span: 8 }` |
| ratio | String | 预览比例<br>`type='file'` | `'1:1'` <br> `'2:1'` <br> `'3:1'` <br> `'3:2'` <br> `'4:3'` <br> `'6:4'` <br> `'16:9'` | `'1:1'` |
| bgSize | String | 预览背景尺寸<br>`type='file'` | `'cover'` <br> `'contain'` | `'cover'` |
| fileUrlAppend | String | 文件在打开时url的附加信息<br>`type='file'` | -- | `'*'` |
| filePreviewAppend | String | 文件在预览时url的附加信息<br>`type='file'` | -- | `'*'` |
| --- __功能相关__ --- |
| name | String | 表单提交时的 name | -- | -- |
| emptyNoPost | Boolean | 数据为空时是否提交 | `true`<br>`false` | `false` |
| rules | Array | 数据验证规则 | https://github.com/yiminghe/async-validator | -- |
| datasource | Array | 数据源配置<br>`type='radio'`<br>`type='checkbox'`<br>`type='select'` | -- | -- |
| labelKey | String | 选项显示文字<br>`datasource[labelKey]` | -- | `'name'` |
| valueKey | String | 选项选中值<br>`datasource[valueKey]` | -- | `'value'` |
| min | Number | 最少数量<br>`type='checkbox'`<br>最小数值<br>`type='slider'` | `>= 0` | `0`
| max | Number | 最多数量: <br>`type='checkbox'`<br>`type='select'`<br>`type='file'`<br>最大数值<br>`type='slider'` | `>= 0` | `0` (0: 无限制)
| multiple | Boolean | 是否可多选<br>`type='select'`<br>`type='file'` | `true`<br>`false` | `false`
| clearable | Boolean | 是否可清楚数据<br>`type='select'` | `true`<br>`false` | `true` |
| step | Number | 步长<br>`type='slider'`
| showInput | Boolean | 是否显示输入框<br>`type='slider'` | `true`<br>`false` | `false` |
| showStops | Boolean | 是否显示间断点<br>`type='slider'` | `true`<br>`false` | `false` |
| showTooltip | Boolean | 是否显示提示文字<br>`type='slider'` | `true`<br>`false` | `false` |
| range | Boolean | 是否范围选取<br>`type='slider'` | `true`<br>`false` | `false` |
| extensions | String | 可选文件类型<br>`type='file'` | -- | `'*'` |
| --- __事件相关__ --- |
| onChange | Function (value)<br>- value: Any | 数据变更时触发 | -- | `$emit('input')` |
| onFileClick | Function(url, data)<br>- url: String<br>- data: [String, Object] | 点击预览时触发 | -- | -- |
| onFileChooseError | Function () | 文件选取失败时触发 | -- | -- |
| onFilePreviewError | Function () | 文件预览失败时触发 | -- | -- |
| --- __其他___ --- |
| value | Any | 数据值绑定<br>`v-model` | -- | `''` |
| configs | Object | 所有 props 集合 | -- | `{}` |

==> vuejs-1.0.27.tgz: package/docs/element-ui/form.md <==
## 基于 element-ui 表单组件封装扩展
| 组件名称 | 组件路径 | 组件说明
| :--- | :--- | :--- |
| nftn-el-input | /components/element-ui/form/input.vue | 输入组件 |
| nftn-el-form | /components/element-ui/form/main.vue | 表单组件 |

### 依赖内容
| 依赖名称 | 依赖路径 | 依赖说明
| :--- | :--- | :--- |
| nftn-el-grid | /components/element-ui/grid/main.vue | 内部网格组件 |
| moxie-file | /component/moxie/file.vue | moxie 文件组件 |
| moxie-preview | /component/moxie/preview.vue | moxie 文件组件 |
| el-radio-group + el-radio | http://element.eleme.io/#/zh-CN/component/radio | element-ui 单选组件 |
| el-checkbox-group + el-checkbox | http://element.eleme.io/#/zh-CN/component/checkbox | element-ui 复选组件 |
| el-select | http://element.eleme.io/#/zh-CN/component/select | element-ui 下拉组件 |
| el-date-picker | http://element.eleme.io/#/zh-CN/component/date-picker | element-ui 日期组件 |
| el-switch | http://element.eleme.io/#/zh-CN/component/switch | element-ui 开关组件 |
| el-slider | http://element.eleme.io/#/zh-CN/component/slider | element-ui 滑块组件 |
| el-input | http://element.eleme.io/#/zh-CN/component/input | element-ui 输入组件 |
| el-form + el-form-item | http://element.eleme.io/#/zh-CN/component/form | element-ui 表单组件 |

### props
#### /components/element-ui/form.vue
| 参数名称 | 参数类型 | 参数说明 | 可选值 | 默认值 |
| :--- | :--- | :--- | :--- | :--- |
| --- __显示相关__ --- |
| grid | [Object, Array] | 表单网格布局 | /components/element-ui/grid/main.vue | `{}` |
| actionGridSlot | String | 表单按钮所在网格位置 | 网格范围 | 网格最后一格<br>`(rows.length - 1) + '-' + (cols.length - 1)` |
| labelPosition | String | 表单名称显示位置 | `'top'`<br>`'left'`<br>`'right'` | `'top'`
| labelWidth | Number | 表单名称显示长度 | -- | `80` |
| inputs | Array | 表单项集合 | /components/element-ui/input.vue | -- |
| --- __功能相关__ --- |
| rules | Object | 规则自动合并到 input.rules 数组中 | -- | `{}` |
| emptyNoPost | Boolean | 数据为空时是否提交<br>表单项单独配置为准 | `true`<br>`false` | `false` |
| --- __其他___ --- |
| value | Any | 数据值绑定<br>`v-model` | -- | '' |

#### /components/element-ui/input.vue
| 参数名称 | 参数类型 | 参数说明 | 可选值 | 默认值 |
| :--- | :--- | :--- | :--- | :--- |
| --- __显示相关__ --- |
| label | String | 输入项名称 | -- | -- |
| type | String | 输入项类型 | `'radio'`<br>`'checkbox'`<br>`'select'`<br>`'date'`<br>`'daterange'`<br>`'switch'`<br>`'slider'`<br>`'file'`<br>`'text'` | `'text'` |
| disabled | Boolean | 是否禁用 | `true`<br>`false` | `false` |
| errors | Array | 输入项错误信息 |  -- | -- |
| rows | Number | 文本行数<br>`type='textarea'` | -- | `3` |
| format | String | 日期显示格式<br>`type='date'`<br>`type='datetime'` | -- | `'yyyy-MM-dd'` |
| onText | String | 打开时显示文字<br>`type='switch'` | -- | `'开`' |
| offText | String | 关闭时显示文字<br>`type='switch'` | -- | `'关'` |
| onValue | Any | 打开时数据值<br>`type='switch'` | -- | `true` |
| offValue | Any | 关闭时数据值<br>`type='switch'` | -- | `false` |
| onColor | String | 打开时显示颜色<br>`type='switch'`<br> | -- | `'#20A0FF'` |
| offColor | String | 关闭时显示颜色<br>`type='switch'`<br> | -- | `'#C0CCDA'` |
| vertical | Boolean | 是否纵向显示<br>`type='switch'` | `true`<br>`false`| `false` |
| height | String | 设定高度值<br>`type='switch'` | `?? + 'px'` | `'100px'` |
| grid | Object | 网格展示<br>`type='file'` | /components/element-ui/grid/main.vue | `{ gap: 10, span: 8 }` |
| ratio | String | 预览比例<br>`type='file'` | `'1:1'` <br> `'2:1'` <br> `'3:1'` <br> `'3:2'` <br> `'4:3'` <br> `'6:4'` <br> `'16:9'` | `'1:1'` |
| bgSize | String | 预览背景尺寸<br>`type='file'` | `'cover'` <br> `'contain'` | `'cover'` |
| fileUrlAppend | String | 文件在打开时url的附加信息<br>`type='file'` | -- | `'*'` |
| filePreviewAppend | String | 文件在预览时url的附加信息<br>`type='file'` | -- | `'*'` |
| --- __功能相关__ --- |
| name | String | 表单提交时的 name | -- | -- |
| emptyNoPost | Boolean | 数据为空时是否提交 | `true`<br>`false` | `false` |
| rules | Array | 数据验证规则 | https://github.com/yiminghe/async-validator | -- |
| datasource | Array | 数据源配置<br>`type='radio'`<br>`type='checkbox'`<br>`type='select'` | -- | -- |
| labelKey | String | 选项显示文字<br>`datasource[labelKey]` | -- | `'name'` |
| valueKey | String | 选项选中值<br>`datasource[valueKey]` | -- | `'value'` |
| min | Number | 最少数量<br>`type='checkbox'`<br>最小数值<br>`type='slider'` | `>= 0` | `0`
| max | Number | 最多数量: <br>`type='checkbox'`<br>`type='select'`<br>`type='file'`<br>最大数值<br>`type='slider'` | `>= 0` | `0` (0: 无限制)
| multiple | Boolean | 是否可多选<br>`type='select'`<br>`type='file'` | `true`<br>`false` | `false`
| clearable | Boolean | 是否可清楚数据<br>`type='select'` | `true`<br>`false` | `true` |
| step | Number | 步长<br>`type='slider'`
| showInput | Boolean | 是否显示输入框<br>`type='slider'` | `true`<br>`false` | `false` |
| showStops | Boolean | 是否显示间断点<br>`type='slider'` | `true`<br>`false` | `false` |
| showTooltip | Boolean | 是否显示提示文字<br>`type='slider'` | `true`<br>`false` | `false` |
| range | Boolean | 是否范围选取<br>`type='slider'` | `true`<br>`false` | `false` |
| extensions | String | 可选文件类型<br>`type='file'` | -- | `'*'` |
| --- __事件相关__ --- |
| onChange | Function (value)<br>- value: Any | 数据变更时触发 | -- | `$emit('input')` |
| onFileClick | Function(url, data)<br>- url: String<br>- data: [String, Object] | 点击预览时触发 | -- | `$confirm(...) + $message(...)` <br> http://element.eleme.io/#/zh-CN/component/message-box |
| onFileChooseError | Function () | 文件选取失败时触发 | -- | -- |
| onFilePreviewError | Function () | 文件预览失败时触发 | -- | -- |
| --- __其他___ --- |
| value | Any | 数据值绑定<br>`v-model` | -- | `''` |
| configs | Object | 所有 props 集合 | -- | `{}` |
